//
//  Extends.m
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

#import "Extends.h"

@implementation NSData (Extensions)

- (NSString *)toHexString {
    NSMutableString *hexString = [NSMutableString stringWithCapacity:self.length * 2];
    const unsigned char *dataBuffer = (const unsigned char *)[self bytes];
    
    for (int i = 0; i < self.length; ++i) {
        [hexString appendFormat:@"%02X", dataBuffer[i]];
    }
    
    return [hexString copy];
}

- (NSString *)toHexAscii {
    return [[NSString alloc] initWithData:self encoding:NSASCIIStringEncoding];
}

@end

@implementation UIAlertController (Extensions)

+ (void)showAlert:(UIViewController *)viewController
                 title:(NSString *)title
               message:(NSString *)message
                 lists:(NSArray<NSString *> *)lists
            cancelTitle:(NSString *)cancelTitle
         selectionHandler:(void (^)(NSInteger selectedIndex))selectionHandler {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:title
                                                                   message:message
                                                            preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger index = 0; index < lists.count; index++) {
        NSString *item = lists[index];
        UIAlertAction *action = [UIAlertAction actionWithTitle:item
                                                         style:UIAlertActionStyleDefault
                                                       handler:^(UIAlertAction * _Nonnull action) {
            if (selectionHandler) {
                selectionHandler(index);
            }
        }];
        [alert addAction:action];
    }
    
    UIAlertAction *cancelAction = [UIAlertAction actionWithTitle:cancelTitle
                                                           style:UIAlertActionStyleCancel
                                                         handler:nil];
    [alert addAction:cancelAction];
    
    [viewController presentViewController:alert animated:YES completion:nil];
}

+ (void)showSelectAlert:(UIViewController *)viewController
                       title:(NSString *)title
                     message:(NSString *)message
                       lists:(NSArray<NSString *> *)lists
                  cancelTitle:(NSString *)cancelTitle
                     itemName:(NSString *)itemName
              selectionHandler:(void (^)(NSInteger selectedIndex))selectionHandler {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:title
                                                                   message:message
                                                            preferredStyle:UIAlertControllerStyleAlert];
    
    for (NSInteger index = 0; index < lists.count; index++) {
        NSString *messageTitle = lists[index];
        if ([itemName isEqualToString:lists[index]]) {
            messageTitle = [NSString stringWithFormat:@"✔️ %@", lists[index]];
        }
        
        UIAlertAction *action = [UIAlertAction actionWithTitle:messageTitle
                                                         style:UIAlertActionStyleDefault
                                                       handler:^(UIAlertAction * _Nonnull action) {
            if (selectionHandler) {
                selectionHandler(index);
            }
        }];
        [alert addAction:action];
    }
    
    UIAlertAction *cancelAction = [UIAlertAction actionWithTitle:cancelTitle
                                                           style:UIAlertActionStyleCancel
                                                         handler:nil];
    [alert addAction:cancelAction];
    
    [viewController presentViewController:alert animated:YES completion:nil];
}

+ (void)showOkAlert:(UIViewController *)viewController
                  title:(NSString *)title
                message:(NSString *)message {
    UIAlertController *alert = [UIAlertController alertControllerWithTitle:title
                                                                   message:message
                                                            preferredStyle:UIAlertControllerStyleAlert];
    UIAlertAction *action = [UIAlertAction actionWithTitle:@"OK"
                                                     style:UIAlertActionStyleDefault
                                                   handler:nil];
    [alert addAction:action];
    [viewController presentViewController:alert animated:YES completion:nil];
}

@end

@implementation NSUserDefaults (Extensions)

- (BOOL)boolForKey:(NSString *)key defaultValue:(BOOL)defaultValue {
    NSNumber *value = [self objectForKey:key];
    return (value != nil) ? [value boolValue] : defaultValue;
}

@end
