//
//  ReaderModel.m
//  AsReaderScan
//
//  Created by Mikiko on 11/7/24.
//  Copyright © 2024 SPS INC. All rights reserved.
//

// ReaderModel.m
#import "ReaderModel.h"

@implementation ReaderInfo

- (instancetype)init {
    self = [super init];
    if (self) {
        _battery = 0;
        _codeID = CodeIDNone;
        _selectItem = 0;
        _sleepTime = 0;
        
        _appBeep = [[NSUserDefaults standardUserDefaults] boolForKey:@"App Beep"];
        _triggerMode = [[NSUserDefaults standardUserDefaults] boolForKey:@"Trigger Mode"];
        _ssiBeep = [[NSUserDefaults standardUserDefaults] boolForKey:@"SSI Beep"];
        _continuousReading = [[NSUserDefaults standardUserDefaults] boolForKey:@"Continuous Reading"];
    }
    return self;
}

- (void)setAppBeep:(BOOL)appBeep {
    _appBeep = appBeep;
    [[NSUserDefaults standardUserDefaults] setBool:appBeep forKey:@"App Beep"];
}

- (void)setTriggerMode:(BOOL)triggerMode {
    _triggerMode = triggerMode;
    [[NSUserDefaults standardUserDefaults] setBool:triggerMode forKey:@"Trigger Mode"];
}

- (void)setSsiBeep:(BOOL)ssiBeep {
    _ssiBeep = ssiBeep;
    [[NSUserDefaults standardUserDefaults] setBool:ssiBeep forKey:@"SSI Beep"];
}

+ (NSInteger)sleepTimeFromIndex:(NSInteger)index {
    switch (index) {
        case 0: return 5;
        case 1: return 30;
        case 2: return 60;
        case 3: return 120;
        default: return 0;
    }
}

+ (NSString *)sleepTimeStringFromIndex:(NSInteger)index {
    switch (index) {
        case 5: return @"Min5";
        case 30: return @"Min30";
        case 60: return @"Min60";
        case 120: return @"Min120";
        case 0: return @"NonSleep";
        default: return @"";
    }
}

+ (NSArray<NSString *> *)sleepTimeArray {
    return @[@"Min5", @"Min30", @"Min60", @"Min120", @"NonSleep"];
}

+ (CodeID)codeIDFromIndex:(NSInteger)index {
    switch (index) {
        case 0: return CodeIDNone;
        case 1: return CodeIDAim;
        case 2: return CodeIDSymbol;
        default: return CodeIDNone;
    }
}

+ (NSArray<NSString *> *)codeIDArray {
    return @[@"None", @"Aim", @"Symbol"];
}

+ (TypeOCR)ocrFromIndex:(NSInteger)index {
    switch (index) {
        case 0: return OCRNone;
        case 1: return OCRA;
        case 2: return OCRB;
        case 3: return OCRAB;
        default: return OCRNone;
    }
}

+ (NSArray<NSString *> *)ocrArray {
    return @[@"OCRNONE", @"OCRA", @"OCRB", @"OCRAB"];
}

@end
